@@ -1,7 +1,7 @@
 /* File names and variables for bison,
 
-   Copyright (C) 1984, 1989, 2000, 2001, 2002, 2006, 2007 Free Software
-   Foundation, Inc.
+   Copyright (C) 1984, 1989, 2000-2002, 2006-2007, 2009-2010 Free
+   Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -63,7 +63,7 @@ extern char *all_but_ext;
 
 void compute_output_file_names (void);
 void output_file_names_free (void);
-void output_file_name_check (char const *file_name);
+void output_file_name_check (char **file_name);
 
 FILE *xfopen (const char *name, const char *mode);
 void xfclose (FILE *ptr);
