@@ -1,7 +1,7 @@
 /* Parse command line arguments for Bison.
 
-   Copyright (C) 1984, 1986, 1989, 1992, 2000, 2001, 2002, 2003, 2004,
-   2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1986, 1989, 1992, 2000-2010 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -265,7 +265,7 @@ Operation modes:\n\
       --print-localedir      output directory containing locale-dependent data\n\
       --print-datadir        output directory containing skeletons and XSLT\n\
   -y, --yacc                 emulate POSIX Yacc\n\
-  -W, --warnings=[CATEGORY]  report the warnings falling in CATEGORY\n\
+  -W, --warnings[=CATEGORY]  report the warnings falling in CATEGORY\n\
 \n\
 "), stdout);
 
