@@ -1,10 +1,9 @@
-
-/* A Bison parser, made by GNU Bison 2.3b.21-d67c5-dirty.  */
+/* A Bison parser, made by GNU Bison 2.4.1.61-f1ce.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2006, 2009-2010 Free Software
+   Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -46,7 +45,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3b.21-d67c5-dirty"
+#define YYBISON_VERSION "2.4.1.61-f1ce"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -79,8 +78,7 @@
 #line 1 "parse-gram.y"
 /* Bison Grammar Parser                             -*- C -*-
 
-   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software
-   Foundation, Inc.
+   Copyright (C) 2002-2010 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -151,7 +149,7 @@ static int current_prec = 0;
 
 
 /* Line 189 of yacc.c  */
-#line 155 "parse-gram.c"
+#line 153 "parse-gram.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -299,8 +297,8 @@ static int current_prec = 0;
 typedef union YYSTYPE
 {
 
-/* Line 222 of yacc.c  */
-#line 92 "parse-gram.y"
+/* Line 214 of yacc.c  */
+#line 91 "parse-gram.y"
 
   symbol *symbol;
   symbol_list *list;
@@ -313,8 +311,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 222 of yacc.c  */
-#line 318 "parse-gram.c"
+/* Line 214 of yacc.c  */
+#line 316 "parse-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -339,7 +337,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 343 "parse-gram.c"
+#line 341 "parse-gram.c"
 
 #ifdef short
 # undef short
@@ -389,7 +387,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if YYENABLE_NLS
+# if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -664,17 +662,17 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   202,   202,   210,   212,   216,   217,   227,   228,   232,
-     233,   238,   239,   240,   241,   242,   243,   248,   257,   258,
-     259,   260,   261,   262,   263,   264,   265,   266,   267,   280,
-     281,   305,   306,   307,   308,   312,   313,   314,   318,   325,
-     332,   336,   340,   347,   362,   363,   367,   379,   379,   384,
-     384,   389,   400,   415,   416,   417,   421,   422,   427,   429,
-     434,   435,   440,   442,   447,   448,   452,   453,   454,   455,
-     460,   465,   470,   476,   482,   493,   494,   503,   504,   510,
-     511,   512,   519,   519,   523,   524,   525,   530,   531,   533,
-     535,   537,   539,   549,   550,   556,   559,   568,   588,   590,
-     599,   604,   605,   610,   617,   619
+       0,   201,   201,   209,   211,   215,   216,   226,   227,   231,
+     232,   237,   238,   239,   240,   241,   242,   247,   256,   257,
+     258,   259,   260,   261,   262,   263,   264,   265,   266,   279,
+     280,   304,   305,   306,   307,   311,   312,   313,   317,   324,
+     331,   335,   339,   346,   361,   362,   366,   378,   378,   383,
+     383,   388,   399,   414,   415,   416,   420,   421,   426,   428,
+     433,   434,   439,   441,   446,   447,   451,   452,   453,   454,
+     459,   464,   469,   475,   481,   492,   493,   502,   503,   509,
+     510,   511,   518,   518,   522,   523,   524,   529,   530,   532,
+     534,   536,   538,   548,   549,   555,   558,   567,   587,   589,
+     598,   603,   604,   609,   616,   618
 };
 #endif
 
@@ -894,9 +892,18 @@ static const yytype_uint8 yystos[] =
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
-   Once GCC version 2 has supplanted version 1, this can go.  */
+   Once GCC version 2 has supplanted version 1, this can go.  However,
+   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
+   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
+   discussed.  */
 
 #define YYFAIL		goto yyerrlab
+#if defined YYFAIL
+  /* This is here to suppress warnings from the GCC cpp's
+     -Wunused-macros.  Normally we don't worry about that warning, but
+     some users do, and we want to make it easy for users to remove
+     YYFAIL uses, which will produce warnings from Bison 2.5.  */
+#endif
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
@@ -953,7 +960,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -1029,147 +1036,147 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep, yylocationp)
     {
       case 3: /* "\"string\"" */
 
-/* Line 715 of yacc.c  */
-#line 180 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 179 "parse-gram.y"
 	{ fputs (quotearg_style (c_quoting_style, (yyvaluep->chars)), stderr); };
 
-/* Line 715 of yacc.c  */
-#line 1038 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1045 "parse-gram.c"
 	break;
       case 4: /* "\"integer\"" */
 
-/* Line 715 of yacc.c  */
-#line 191 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 190 "parse-gram.y"
 	{ fprintf (stderr, "%d", (yyvaluep->integer)); };
 
-/* Line 715 of yacc.c  */
-#line 1047 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1054 "parse-gram.c"
 	break;
       case 43: /* "\"{...}\"" */
 
-/* Line 715 of yacc.c  */
-#line 182 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 181 "parse-gram.y"
 	{ fprintf (stderr, "{\n%s\n}", (yyvaluep->code)); };
 
-/* Line 715 of yacc.c  */
-#line 1056 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1063 "parse-gram.c"
 	break;
       case 44: /* "\"char\"" */
 
-/* Line 715 of yacc.c  */
-#line 174 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 173 "parse-gram.y"
 	{ fputs (char_name ((yyvaluep->character)), stderr); };
 
-/* Line 715 of yacc.c  */
-#line 1065 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1072 "parse-gram.c"
 	break;
       case 45: /* "\"epilogue\"" */
 
-/* Line 715 of yacc.c  */
-#line 182 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 181 "parse-gram.y"
 	{ fprintf (stderr, "{\n%s\n}", (yyvaluep->chars)); };
 
-/* Line 715 of yacc.c  */
-#line 1074 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1081 "parse-gram.c"
 	break;
       case 47: /* "\"identifier\"" */
 
-/* Line 715 of yacc.c  */
-#line 187 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 186 "parse-gram.y"
 	{ fputs ((yyvaluep->uniqstr), stderr); };
 
-/* Line 715 of yacc.c  */
-#line 1083 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1090 "parse-gram.c"
 	break;
       case 48: /* "\"identifier:\"" */
 
-/* Line 715 of yacc.c  */
-#line 188 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 187 "parse-gram.y"
 	{ fprintf (stderr, "%s:", (yyvaluep->uniqstr)); };
 
-/* Line 715 of yacc.c  */
-#line 1092 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1099 "parse-gram.c"
 	break;
       case 51: /* "\"%{...%}\"" */
 
-/* Line 715 of yacc.c  */
-#line 182 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 181 "parse-gram.y"
 	{ fprintf (stderr, "{\n%s\n}", (yyvaluep->chars)); };
 
-/* Line 715 of yacc.c  */
-#line 1101 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1108 "parse-gram.c"
 	break;
       case 53: /* "\"type\"" */
 
-/* Line 715 of yacc.c  */
-#line 186 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 185 "parse-gram.y"
 	{ fprintf (stderr, "<%s>", (yyvaluep->uniqstr)); };
 
-/* Line 715 of yacc.c  */
-#line 1110 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1117 "parse-gram.c"
 	break;
       case 82: /* "variable" */
 
-/* Line 715 of yacc.c  */
-#line 187 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 186 "parse-gram.y"
 	{ fputs ((yyvaluep->uniqstr), stderr); };
 
-/* Line 715 of yacc.c  */
-#line 1119 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1126 "parse-gram.c"
 	break;
       case 83: /* "content.opt" */
 
-/* Line 715 of yacc.c  */
-#line 182 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 181 "parse-gram.y"
 	{ fprintf (stderr, "{\n%s\n}", (yyvaluep->chars)); };
 
-/* Line 715 of yacc.c  */
-#line 1128 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1135 "parse-gram.c"
 	break;
       case 84: /* "braceless" */
 
-/* Line 715 of yacc.c  */
-#line 182 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 181 "parse-gram.y"
 	{ fprintf (stderr, "{\n%s\n}", (yyvaluep->chars)); };
 
-/* Line 715 of yacc.c  */
-#line 1137 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1144 "parse-gram.c"
 	break;
       case 85: /* "id" */
 
-/* Line 715 of yacc.c  */
-#line 194 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 193 "parse-gram.y"
 	{ fprintf (stderr, "%s", (yyvaluep->symbol)->tag); };
 
-/* Line 715 of yacc.c  */
-#line 1146 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1153 "parse-gram.c"
 	break;
       case 86: /* "id_colon" */
 
-/* Line 715 of yacc.c  */
-#line 195 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 194 "parse-gram.y"
 	{ fprintf (stderr, "%s:", (yyvaluep->symbol)->tag); };
 
-/* Line 715 of yacc.c  */
-#line 1155 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1162 "parse-gram.c"
 	break;
       case 87: /* "symbol" */
 
-/* Line 715 of yacc.c  */
-#line 194 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 193 "parse-gram.y"
 	{ fprintf (stderr, "%s", (yyvaluep->symbol)->tag); };
 
-/* Line 715 of yacc.c  */
-#line 1164 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1171 "parse-gram.c"
 	break;
       case 88: /* "string_as_id" */
 
-/* Line 715 of yacc.c  */
-#line 194 "parse-gram.y"
+/* Line 724 of yacc.c  */
+#line 193 "parse-gram.y"
 	{ fprintf (stderr, "%s", (yyvaluep->symbol)->tag); };
 
-/* Line 715 of yacc.c  */
-#line 1173 "parse-gram.c"
+/* Line 724 of yacc.c  */
+#line 1180 "parse-gram.c"
 	break;
       default:
 	break;
@@ -1680,7 +1687,7 @@ YYLTYPE yylloc;
   yyvsp = yyvs;
   yylsp = yyls;
 
-#if YYLTYPE_IS_TRIVIAL
+#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
   yylloc.first_column = yylloc.last_column = 1;
@@ -1688,8 +1695,8 @@ YYLTYPE yylloc;
 
 /* User initialization code.  */
 
-/* Line 1248 of yacc.c  */
-#line 84 "parse-gram.y"
+/* Line 1251 of yacc.c  */
+#line 83 "parse-gram.y"
 {
   /* Bison's grammar can initial empty locations, hence a default
      location is needed. */
@@ -1697,8 +1704,8 @@ YYLTYPE yylloc;
   boundary_set (&yylloc.end, current_file, 1, 1);
 }
 
-/* Line 1248 of yacc.c  */
-#line 1702 "parse-gram.c"
+/* Line 1251 of yacc.c  */
+#line 1709 "parse-gram.c"
   yylsp[0] = yylloc;
 
   goto yysetstate;
@@ -1885,8 +1892,8 @@ yyreduce:
     {
         case 6:
 
-/* Line 1455 of yacc.c  */
-#line 218 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 217 "parse-gram.y"
     {
       code_props plain_code;
       code_props_plain_init (&plain_code, (yyvsp[(1) - (1)].chars), (yylsp[(1) - (1)]));
@@ -1900,15 +1907,15 @@ yyreduce:
 
   case 7:
 
-/* Line 1455 of yacc.c  */
-#line 227 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 226 "parse-gram.y"
     { debug_flag = true; }
     break;
 
   case 8:
 
-/* Line 1455 of yacc.c  */
-#line 229 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 228 "parse-gram.y"
     {
       muscle_percent_define_insert ((yyvsp[(2) - (3)].uniqstr), (yylsp[(2) - (3)]), (yyvsp[(3) - (3)].chars));
     }
@@ -1916,15 +1923,15 @@ yyreduce:
 
   case 9:
 
-/* Line 1455 of yacc.c  */
-#line 232 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 231 "parse-gram.y"
     { defines_flag = true; }
     break;
 
   case 10:
 
-/* Line 1455 of yacc.c  */
-#line 234 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 233 "parse-gram.y"
     {
       defines_flag = true;
       spec_defines_file = xstrdup ((yyvsp[(2) - (2)].chars));
@@ -1933,43 +1940,43 @@ yyreduce:
 
   case 11:
 
-/* Line 1455 of yacc.c  */
-#line 238 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 237 "parse-gram.y"
     { error_verbose = true; }
     break;
 
   case 12:
 
-/* Line 1455 of yacc.c  */
-#line 239 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 238 "parse-gram.y"
     { expected_sr_conflicts = (yyvsp[(2) - (2)].integer); }
     break;
 
   case 13:
 
-/* Line 1455 of yacc.c  */
-#line 240 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 239 "parse-gram.y"
     { expected_rr_conflicts = (yyvsp[(2) - (2)].integer); }
     break;
 
   case 14:
 
-/* Line 1455 of yacc.c  */
-#line 241 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 240 "parse-gram.y"
     { spec_file_prefix = (yyvsp[(2) - (2)].chars); }
     break;
 
   case 15:
 
-/* Line 1455 of yacc.c  */
-#line 242 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 241 "parse-gram.y"
     { spec_file_prefix = (yyvsp[(3) - (3)].chars); }
     break;
 
   case 16:
 
-/* Line 1455 of yacc.c  */
-#line 244 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 243 "parse-gram.y"
     {
       nondeterministic_parser = true;
       glr_parser = true;
@@ -1978,8 +1985,8 @@ yyreduce:
 
   case 17:
 
-/* Line 1455 of yacc.c  */
-#line 249 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 248 "parse-gram.y"
     {
       code_props action;
       code_props_symbol_action_init (&action, (yyvsp[(2) - (2)].code), (yylsp[(2) - (2)]));
@@ -1992,78 +1999,78 @@ yyreduce:
 
   case 18:
 
-/* Line 1455 of yacc.c  */
-#line 257 "parse-gram.y"
-    { language_argmatch ((yyvsp[(2) - (2)].chars), 1, &(yylsp[(1) - (2)])); }
+/* Line 1464 of yacc.c  */
+#line 256 "parse-gram.y"
+    { language_argmatch ((yyvsp[(2) - (2)].chars), grammar_prio, &(yylsp[(1) - (2)])); }
     break;
 
   case 19:
 
-/* Line 1455 of yacc.c  */
-#line 258 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 257 "parse-gram.y"
     { add_param ("lex_param", (yyvsp[(2) - (2)].code), (yylsp[(2) - (2)])); }
     break;
 
   case 20:
 
-/* Line 1455 of yacc.c  */
-#line 259 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 258 "parse-gram.y"
     { locations_flag = true; }
     break;
 
   case 21:
 
-/* Line 1455 of yacc.c  */
-#line 260 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 259 "parse-gram.y"
     { spec_name_prefix = (yyvsp[(2) - (2)].chars); }
     break;
 
   case 22:
 
-/* Line 1455 of yacc.c  */
-#line 261 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 260 "parse-gram.y"
     { spec_name_prefix = (yyvsp[(3) - (3)].chars); }
     break;
 
   case 23:
 
-/* Line 1455 of yacc.c  */
-#line 262 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 261 "parse-gram.y"
     { no_lines_flag = true; }
     break;
 
   case 24:
 
-/* Line 1455 of yacc.c  */
-#line 263 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 262 "parse-gram.y"
     { nondeterministic_parser = true; }
     break;
 
   case 25:
 
-/* Line 1455 of yacc.c  */
-#line 264 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 263 "parse-gram.y"
     { spec_outfile = (yyvsp[(2) - (2)].chars); }
     break;
 
   case 26:
 
-/* Line 1455 of yacc.c  */
-#line 265 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 264 "parse-gram.y"
     { spec_outfile = (yyvsp[(3) - (3)].chars); }
     break;
 
   case 27:
 
-/* Line 1455 of yacc.c  */
-#line 266 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 265 "parse-gram.y"
     { add_param ("parse_param", (yyvsp[(2) - (2)].code), (yylsp[(2) - (2)])); }
     break;
 
   case 28:
 
-/* Line 1455 of yacc.c  */
-#line 268 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 267 "parse-gram.y"
     {
       /* %pure-parser is deprecated in favor of `%define api.pure', so use
          `%define api.pure' in a backward-compatible manner here.  First, don't
@@ -2080,15 +2087,15 @@ yyreduce:
 
   case 29:
 
-/* Line 1455 of yacc.c  */
-#line 280 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 279 "parse-gram.y"
     { version_check (&(yylsp[(2) - (2)]), (yyvsp[(2) - (2)].chars)); }
     break;
 
   case 30:
 
-/* Line 1455 of yacc.c  */
-#line 282 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 281 "parse-gram.y"
     {
       char const *skeleton_user = (yyvsp[(2) - (2)].chars);
       if (strchr (skeleton_user, '/'))
@@ -2110,35 +2117,35 @@ yyreduce:
           skeleton_user = uniqstr_new (skeleton_build);
           free (skeleton_build);
         }
-      skeleton_arg (skeleton_user, 1, &(yylsp[(1) - (2)]));
+      skeleton_arg (skeleton_user, grammar_prio, &(yylsp[(1) - (2)]));
     }
     break;
 
   case 31:
 
-/* Line 1455 of yacc.c  */
-#line 305 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 304 "parse-gram.y"
     { token_table_flag = true; }
     break;
 
   case 32:
 
-/* Line 1455 of yacc.c  */
-#line 306 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 305 "parse-gram.y"
     { report_flag |= report_states; }
     break;
 
   case 33:
 
-/* Line 1455 of yacc.c  */
-#line 307 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 306 "parse-gram.y"
     { yacc_flag = true; }
     break;
 
   case 37:
 
-/* Line 1455 of yacc.c  */
-#line 315 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 314 "parse-gram.y"
     {
       grammar_start_symbol_set ((yyvsp[(2) - (2)].symbol), (yylsp[(2) - (2)]));
     }
@@ -2146,8 +2153,8 @@ yyreduce:
 
   case 38:
 
-/* Line 1455 of yacc.c  */
-#line 319 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 318 "parse-gram.y"
     {
       symbol_list *list;
       for (list = (yyvsp[(3) - (3)].list); list; list = list->next)
@@ -2158,8 +2165,8 @@ yyreduce:
 
   case 39:
 
-/* Line 1455 of yacc.c  */
-#line 326 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 325 "parse-gram.y"
     {
       symbol_list *list;
       for (list = (yyvsp[(3) - (3)].list); list; list = list->next)
@@ -2170,8 +2177,8 @@ yyreduce:
 
   case 40:
 
-/* Line 1455 of yacc.c  */
-#line 333 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 332 "parse-gram.y"
     {
       default_prec = true;
     }
@@ -2179,8 +2186,8 @@ yyreduce:
 
   case 41:
 
-/* Line 1455 of yacc.c  */
-#line 337 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 336 "parse-gram.y"
     {
       default_prec = false;
     }
@@ -2188,8 +2195,8 @@ yyreduce:
 
   case 42:
 
-/* Line 1455 of yacc.c  */
-#line 341 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 340 "parse-gram.y"
     {
       /* Do not invoke muscle_percent_code_grow here since it invokes
          muscle_user_name_list_grow.  */
@@ -2200,8 +2207,8 @@ yyreduce:
 
   case 43:
 
-/* Line 1455 of yacc.c  */
-#line 348 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 347 "parse-gram.y"
     {
       muscle_percent_code_grow ((yyvsp[(2) - (3)].uniqstr), (yylsp[(2) - (3)]), (yyvsp[(3) - (3)].chars), (yylsp[(3) - (3)]));
       code_scanner_last_string_free ();
@@ -2210,22 +2217,22 @@ yyreduce:
 
   case 44:
 
-/* Line 1455 of yacc.c  */
-#line 362 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 361 "parse-gram.y"
     {}
     break;
 
   case 45:
 
-/* Line 1455 of yacc.c  */
-#line 363 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 362 "parse-gram.y"
     { muscle_code_grow ("union_name", (yyvsp[(1) - (1)].uniqstr), (yylsp[(1) - (1)])); }
     break;
 
   case 46:
 
-/* Line 1455 of yacc.c  */
-#line 368 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 367 "parse-gram.y"
     {
       union_seen = true;
       muscle_code_grow ("stype", (yyvsp[(3) - (3)].chars), (yylsp[(3) - (3)]));
@@ -2235,15 +2242,15 @@ yyreduce:
 
   case 47:
 
-/* Line 1455 of yacc.c  */
-#line 379 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 378 "parse-gram.y"
     { current_class = nterm_sym; }
     break;
 
   case 48:
 
-/* Line 1455 of yacc.c  */
-#line 380 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 379 "parse-gram.y"
     {
       current_class = unknown_sym;
       current_type = NULL;
@@ -2252,15 +2259,15 @@ yyreduce:
 
   case 49:
 
-/* Line 1455 of yacc.c  */
-#line 384 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 383 "parse-gram.y"
     { current_class = token_sym; }
     break;
 
   case 50:
 
-/* Line 1455 of yacc.c  */
-#line 385 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 384 "parse-gram.y"
     {
       current_class = unknown_sym;
       current_type = NULL;
@@ -2269,8 +2276,8 @@ yyreduce:
 
   case 51:
 
-/* Line 1455 of yacc.c  */
-#line 390 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 389 "parse-gram.y"
     {
       symbol_list *list;
       tag_seen = true;
@@ -2282,8 +2289,8 @@ yyreduce:
 
   case 52:
 
-/* Line 1455 of yacc.c  */
-#line 401 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 400 "parse-gram.y"
     {
       symbol_list *list;
       ++current_prec;
@@ -2299,127 +2306,127 @@ yyreduce:
 
   case 53:
 
-/* Line 1455 of yacc.c  */
-#line 415 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 414 "parse-gram.y"
     { (yyval.assoc) = left_assoc; }
     break;
 
   case 54:
 
-/* Line 1455 of yacc.c  */
-#line 416 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 415 "parse-gram.y"
     { (yyval.assoc) = right_assoc; }
     break;
 
   case 55:
 
-/* Line 1455 of yacc.c  */
-#line 417 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 416 "parse-gram.y"
     { (yyval.assoc) = non_assoc; }
     break;
 
   case 56:
 
-/* Line 1455 of yacc.c  */
-#line 421 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 420 "parse-gram.y"
     { current_type = NULL; }
     break;
 
   case 57:
 
-/* Line 1455 of yacc.c  */
-#line 422 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 421 "parse-gram.y"
     { current_type = (yyvsp[(1) - (1)].uniqstr); tag_seen = true; }
     break;
 
   case 58:
 
-/* Line 1455 of yacc.c  */
-#line 428 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 427 "parse-gram.y"
     { (yyval.list) = symbol_list_sym_new ((yyvsp[(1) - (1)].symbol), (yylsp[(1) - (1)])); }
     break;
 
   case 59:
 
-/* Line 1455 of yacc.c  */
-#line 430 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 429 "parse-gram.y"
     { (yyval.list) = symbol_list_prepend ((yyvsp[(1) - (2)].list), symbol_list_sym_new ((yyvsp[(2) - (2)].symbol), (yylsp[(2) - (2)]))); }
     break;
 
   case 60:
 
-/* Line 1455 of yacc.c  */
-#line 434 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 433 "parse-gram.y"
     { (yyval.symbol) = (yyvsp[(1) - (1)].symbol); }
     break;
 
   case 61:
 
-/* Line 1455 of yacc.c  */
-#line 435 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 434 "parse-gram.y"
     { (yyval.symbol) = (yyvsp[(1) - (2)].symbol); symbol_user_token_number_set ((yyvsp[(1) - (2)].symbol), (yyvsp[(2) - (2)].integer), (yylsp[(2) - (2)])); }
     break;
 
   case 62:
 
-/* Line 1455 of yacc.c  */
-#line 441 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 440 "parse-gram.y"
     { (yyval.list) = symbol_list_sym_new ((yyvsp[(1) - (1)].symbol), (yylsp[(1) - (1)])); }
     break;
 
   case 63:
 
-/* Line 1455 of yacc.c  */
-#line 443 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 442 "parse-gram.y"
     { (yyval.list) = symbol_list_prepend ((yyvsp[(1) - (2)].list), symbol_list_sym_new ((yyvsp[(2) - (2)].symbol), (yylsp[(2) - (2)]))); }
     break;
 
   case 64:
 
-/* Line 1455 of yacc.c  */
-#line 447 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 446 "parse-gram.y"
     { (yyval.list) = (yyvsp[(1) - (1)].list); }
     break;
 
   case 65:
 
-/* Line 1455 of yacc.c  */
-#line 448 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 447 "parse-gram.y"
     { (yyval.list) = symbol_list_prepend ((yyvsp[(1) - (2)].list), (yyvsp[(2) - (2)].list)); }
     break;
 
   case 66:
 
-/* Line 1455 of yacc.c  */
-#line 452 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 451 "parse-gram.y"
     { (yyval.list) = symbol_list_sym_new ((yyvsp[(1) - (1)].symbol), (yylsp[(1) - (1)])); }
     break;
 
   case 67:
 
-/* Line 1455 of yacc.c  */
-#line 453 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 452 "parse-gram.y"
     { (yyval.list) = symbol_list_type_new ((yyvsp[(1) - (1)].uniqstr), (yylsp[(1) - (1)])); }
     break;
 
   case 68:
 
-/* Line 1455 of yacc.c  */
-#line 454 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 453 "parse-gram.y"
     { (yyval.list) = symbol_list_default_tagged_new ((yylsp[(1) - (1)])); }
     break;
 
   case 69:
 
-/* Line 1455 of yacc.c  */
-#line 455 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 454 "parse-gram.y"
     { (yyval.list) = symbol_list_default_tagless_new ((yylsp[(1) - (1)])); }
     break;
 
   case 70:
 
-/* Line 1455 of yacc.c  */
-#line 461 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 460 "parse-gram.y"
     {
        current_type = (yyvsp[(1) - (1)].uniqstr);
        tag_seen = true;
@@ -2428,8 +2435,8 @@ yyreduce:
 
   case 71:
 
-/* Line 1455 of yacc.c  */
-#line 466 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 465 "parse-gram.y"
     {
        symbol_class_set ((yyvsp[(1) - (1)].symbol), current_class, (yylsp[(1) - (1)]), true);
        symbol_type_set ((yyvsp[(1) - (1)].symbol), current_type, (yylsp[(1) - (1)]));
@@ -2438,8 +2445,8 @@ yyreduce:
 
   case 72:
 
-/* Line 1455 of yacc.c  */
-#line 471 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 470 "parse-gram.y"
     {
       symbol_class_set ((yyvsp[(1) - (2)].symbol), current_class, (yylsp[(1) - (2)]), true);
       symbol_type_set ((yyvsp[(1) - (2)].symbol), current_type, (yylsp[(1) - (2)]));
@@ -2449,8 +2456,8 @@ yyreduce:
 
   case 73:
 
-/* Line 1455 of yacc.c  */
-#line 477 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 476 "parse-gram.y"
     {
       symbol_class_set ((yyvsp[(1) - (2)].symbol), current_class, (yylsp[(1) - (2)]), true);
       symbol_type_set ((yyvsp[(1) - (2)].symbol), current_type, (yylsp[(1) - (2)]));
@@ -2460,8 +2467,8 @@ yyreduce:
 
   case 74:
 
-/* Line 1455 of yacc.c  */
-#line 483 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 482 "parse-gram.y"
     {
       symbol_class_set ((yyvsp[(1) - (3)].symbol), current_class, (yylsp[(1) - (3)]), true);
       symbol_type_set ((yyvsp[(1) - (3)].symbol), current_type, (yylsp[(1) - (3)]));
@@ -2472,8 +2479,8 @@ yyreduce:
 
   case 81:
 
-/* Line 1455 of yacc.c  */
-#line 513 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 512 "parse-gram.y"
     {
       yyerrok;
     }
@@ -2481,78 +2488,78 @@ yyreduce:
 
   case 82:
 
-/* Line 1455 of yacc.c  */
-#line 519 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 518 "parse-gram.y"
     { current_lhs = (yyvsp[(1) - (1)].symbol); current_lhs_location = (yylsp[(1) - (1)]); }
     break;
 
   case 84:
 
-/* Line 1455 of yacc.c  */
-#line 523 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 522 "parse-gram.y"
     { grammar_current_rule_end ((yylsp[(1) - (1)])); }
     break;
 
   case 85:
 
-/* Line 1455 of yacc.c  */
-#line 524 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 523 "parse-gram.y"
     { grammar_current_rule_end ((yylsp[(3) - (3)])); }
     break;
 
   case 87:
 
-/* Line 1455 of yacc.c  */
-#line 530 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 529 "parse-gram.y"
     { grammar_current_rule_begin (current_lhs, current_lhs_location); }
     break;
 
   case 88:
 
-/* Line 1455 of yacc.c  */
-#line 532 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 531 "parse-gram.y"
     { grammar_current_rule_symbol_append ((yyvsp[(2) - (2)].symbol), (yylsp[(2) - (2)])); }
     break;
 
   case 89:
 
-/* Line 1455 of yacc.c  */
-#line 534 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 533 "parse-gram.y"
     { grammar_current_rule_action_append ((yyvsp[(2) - (2)].code), (yylsp[(2) - (2)])); }
     break;
 
   case 90:
 
-/* Line 1455 of yacc.c  */
-#line 536 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 535 "parse-gram.y"
     { grammar_current_rule_prec_set ((yyvsp[(3) - (3)].symbol), (yylsp[(3) - (3)])); }
     break;
 
   case 91:
 
-/* Line 1455 of yacc.c  */
-#line 538 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 537 "parse-gram.y"
     { grammar_current_rule_dprec_set ((yyvsp[(3) - (3)].integer), (yylsp[(3) - (3)])); }
     break;
 
   case 92:
 
-/* Line 1455 of yacc.c  */
-#line 540 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 539 "parse-gram.y"
     { grammar_current_rule_merge_set ((yyvsp[(3) - (3)].uniqstr), (yylsp[(3) - (3)])); }
     break;
 
   case 94:
 
-/* Line 1455 of yacc.c  */
-#line 550 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 549 "parse-gram.y"
     { (yyval.uniqstr) = uniqstr_new ((yyvsp[(1) - (1)].chars)); }
     break;
 
   case 95:
 
-/* Line 1455 of yacc.c  */
-#line 556 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 555 "parse-gram.y"
     {
       (yyval.chars) = "";
     }
@@ -2560,8 +2567,8 @@ yyreduce:
 
   case 97:
 
-/* Line 1455 of yacc.c  */
-#line 569 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 568 "parse-gram.y"
     {
       code_props plain_code;
       (yyvsp[(1) - (1)].code)[strlen ((yyvsp[(1) - (1)].code)) - 1] = '\n';
@@ -2574,15 +2581,15 @@ yyreduce:
 
   case 98:
 
-/* Line 1455 of yacc.c  */
-#line 589 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 588 "parse-gram.y"
     { (yyval.symbol) = symbol_from_uniqstr ((yyvsp[(1) - (1)].uniqstr), (yylsp[(1) - (1)])); }
     break;
 
   case 99:
 
-/* Line 1455 of yacc.c  */
-#line 591 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 590 "parse-gram.y"
     {
       (yyval.symbol) = symbol_get (char_name ((yyvsp[(1) - (1)].character)), (yylsp[(1) - (1)]));
       symbol_class_set ((yyval.symbol), token_sym, (yylsp[(1) - (1)]), false);
@@ -2592,15 +2599,15 @@ yyreduce:
 
   case 100:
 
-/* Line 1455 of yacc.c  */
-#line 599 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 598 "parse-gram.y"
     { (yyval.symbol) = symbol_from_uniqstr ((yyvsp[(1) - (1)].uniqstr), (yylsp[(1) - (1)])); }
     break;
 
   case 103:
 
-/* Line 1455 of yacc.c  */
-#line 611 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 610 "parse-gram.y"
     {
       (yyval.symbol) = symbol_get (quotearg_style (c_quoting_style, (yyvsp[(1) - (1)].chars)), (yylsp[(1) - (1)]));
       symbol_class_set ((yyval.symbol), token_sym, (yylsp[(1) - (1)]), false);
@@ -2609,8 +2616,8 @@ yyreduce:
 
   case 105:
 
-/* Line 1455 of yacc.c  */
-#line 620 "parse-gram.y"
+/* Line 1464 of yacc.c  */
+#line 619 "parse-gram.y"
     {
       code_props plain_code;
       code_props_plain_init (&plain_code, (yyvsp[(2) - (2)].chars), (yylsp[(2) - (2)]));
@@ -2623,8 +2630,8 @@ yyreduce:
 
 
 
-/* Line 1455 of yacc.c  */
-#line 2628 "parse-gram.c"
+/* Line 1464 of yacc.c  */
+#line 2635 "parse-gram.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2842,8 +2849,8 @@ yyreturn:
 
 
 
-/* Line 1675 of yacc.c  */
-#line 630 "parse-gram.y"
+/* Line 1684 of yacc.c  */
+#line 629 "parse-gram.y"
 
 
 
